unit ShowImageUn;
(*     

v 0.2
 *)


interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  ExtCtrls, StdCtrls;

type
  TShowForm = class(TForm)
    Timer: TTimer;
    ScrollBox: TScrollBox;
    Image: TImage;
    InfoTimer: TTimer;
    ImageInfoLbl: TLabel;
    procedure ImageClick(Sender: TObject);
    procedure FormKeyDown(Sender: TObject; var Key: Word;
      Shift: TShiftState);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure FormClick(Sender: TObject);
    procedure TimerTimer(Sender: TObject);
    procedure ImageMouseDown(Sender: TObject; Button: TMouseButton;
      Shift: TShiftState; X, Y: Integer);
    procedure InfoTimerTimer(Sender: TObject);
  private
    { Private declarations }
    procedure PrepareImage;
//      
  public
    { Public declarations }
    procedure AssignImage(Picture:TPicture;ImageStr:string);
    procedure ShowInfoStr;
  end;

(*    ,   
    *)
  procedure CursorShow;
  procedure CursorHide;

var
  ShowForm: TShowForm;
  midx,midy:integer;
  ScalePics:boolean;
  StateCursor:integer=0;
  KeyPressEvent:function(Key:word; Shift:TShiftState):boolean of Object=nil;

implementation

{$R *.DFM}

procedure TShowForm.ImageClick(Sender: TObject);
begin
  Close;
end;

procedure TShowForm.FormKeyDown(Sender: TObject; var Key: Word;
  Shift: TShiftState);
var CloseF:boolean;
begin
  CloseF:=true;
  if @KeyPressEvent<>nil then CloseF:=KeyPressEvent(Key,Shift);
  if CloseF then Close;
end;

procedure TShowForm.PrepareImage; // 
var pw,ph:integer;
  aspect:real;
begin
  ScrollBox.HorzScrollBar.Position:=0;
  ScrollBox.VertScrollBar.Position:=0;
  midx:=Screen.Width div 2;
  midy:=Screen.Height div 2;
  Image.Stretch:=false;
  Image.AutoSize:=false;
  Image.Align:=alNone;
  pw:=Image.Picture.Width;
  ph:=Image.Picture.Height;
  aspect:=pw/ph;
  Image.Left:=0;
  Image.Top:=0;
  if (pw>Screen.Width)or(ph>Screen.Height) then begin
    if ScalePics then begin //   
      Image.Width:=Screen.Width;
      Image.Height:=trunc(Screen.Width/aspect);
      Image.Top:=(Screen.Height - Image.Height) div 2;
      if Image.Height>Screen.Height then begin
        Image.Top:=0;
        Image.Height:=Screen.Height;
        Image.Width:=trunc(Screen.Height*aspect);
        Image.Left:=(Screen.Width - Image.Width) div 2;
      end;
      Image.Stretch:=true;
      Timer.Enabled:=false;
      CursorShow;
    end else begin
      SetCursorPos(midx,midy);
      Image.AutoSize:=true;
      Timer.Enabled:=true;
      CursorHide;
    end;
  end else begin //    
    Image.Align:=alClient;
  end;

end;

procedure TShowForm.FormClose(Sender: TObject; var Action: TCloseAction);
begin
  Timer.Enabled:=false;
  if not ScalePics then CursorShow;
end;

procedure TShowForm.FormClick(Sender: TObject);
begin
  Close;
end;

procedure TShowForm.TimerTimer(Sender: TObject);
var mpos:TPoint;
  dx,dy:integer;
begin
  GetCursorPos(mpos);
  dx:=mpos.x-midx;
  dy:=mpos.y-midy;
  SetCursorPos(midx,midy);
  with ScrollBox do begin
    if (dx<0)and(HorzScrollBar.Position>0) then
      HorzScrollBar.Position:=HorzScrollBar.Position+dx;
    if (dy<0)and(VertScrollBar.Position>0) then
      VertScrollBar.Position:=VertScrollBar.Position+dy;
    if (dx>0)and(HorzScrollBar.Position<HorzScrollBar.Range) then
      HorzScrollBar.Position:=HorzScrollBar.Position+dx;
    if (dy>0)and(VertScrollBar.Position<VertScrollBar.Range) then
      VertScrollBar.Position:=VertScrollBar.Position+dy;
  end;
end;

procedure TShowForm.ImageMouseDown(Sender: TObject; Button: TMouseButton;
  Shift: TShiftState; X, Y: Integer);
begin
//      
  if Button=mbRight then begin
    ScalePics:=not ScalePics;
    PrepareImage;
  end;
end;

procedure CursorShow;
begin
  if StateCursor<0 then StateCursor:=ShowCursor(true);
end;

procedure CursorHide;
begin
  if StateCursor>=0 then StateCursor:=ShowCursor(false);
end;

//      
procedure TShowForm.AssignImage(Picture: TPicture;ImageStr:string);
begin
  if Picture.Graphic=nil then exit;
  Image.Picture.Assign(Picture);
  ImageInfoLbl.Caption:=ImageStr;
  ImageInfoLbl.Hint:=ImageStr;
  ShowInfoStr;
  PrepareImage;
end;
//      
procedure TShowForm.InfoTimerTimer(Sender: TObject);
begin
  if ImageInfoLbl.Transparent then begin
    ImageInfoLbl.Visible:=false;
    InfoTimer.Enabled:=false;
  end else ImageInfoLbl.Transparent:=true;
end;
//   
procedure TShowForm.ShowInfoStr;
begin
  ImageInfoLbl.Transparent:=false;
  ImageInfoLbl.Visible:=true;
  InfoTimer.Enabled:=false;
  InfoTimer.Enabled:=true;
end;

end.
